@@ -1,5 +1,5 @@
-#  tests for pycryptodomex-3.7.0-py37hfa6e2cd_1000 (this is a generated file);
-print('===== testing package: pycryptodomex-3.7.0-py37hfa6e2cd_1000 =====');
+#  tests for pycryptodomex-3.7.2-py37hfa6e2cd_1000 (this is a generated file);
+print('===== testing package: pycryptodomex-3.7.2-py37hfa6e2cd_1000 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import os
@@ -15,14 +15,14 @@ libname = re.escape(os.environ['CONDA_PREFIX']) + '.*(libgmp.*.(dylib|so))'
 
 if not psutil.WINDOWS:
     # The import below will fail if we don't have gmp (on unix)
-    from Cryptodome.Math import _Numbers_gmp as NumbersGMP
+    from Cryptodome.Math import _IntegerGMP as IntegerGMP
 
     # Make sure that gmp is indeed loaded in memory
     p = psutil.Process(os.getpid())
     assert any(bool(re.match(libname, x.path)) for x in p.memory_maps())
 #  --- run_test.py (end) ---
 
-print('===== pycryptodomex-3.7.0-py37hfa6e2cd_1000 OK =====');
+print('===== pycryptodomex-3.7.2-py37hfa6e2cd_1000 OK =====');
 print("import: 'Cryptodome'")
 import Cryptodome
 
